@@ -37,15 +37,17 @@ class OrderPlacementMixin(CheckoutSessionMixin):
     # Default code for the email to send after successful checkout
     communication_type_code = 'ORDER_PLACED'
 
-    def handle_order_placement(self, order_number, basket, total_incl_tax, total_excl_tax, **kwargs):
+    def handle_order_placement(self, order_number, basket, total_incl_tax,
+                               total_excl_tax, user=None, **kwargs):
         """
         Write out the order models and return the appropriate HTTP response
 
         We deliberately pass the basket in here as the one tied to the request
-        isn't necessarily the correct one to use in placing the order.  This can
-        happen when a basket gets frozen.
+        isn't necessarily the correct one to use in placing the order.  This
+        can happen when a basket gets frozen.
         """
-        order = self.place_order(order_number, basket, total_incl_tax, total_excl_tax, **kwargs)
+        order = self.place_order(order_number, basket, total_incl_tax,
+                                 total_excl_tax, user, **kwargs)
         basket.set_as_submitted()
         return self.handle_successful_order(order)
 
@@ -79,11 +81,12 @@ class OrderPlacementMixin(CheckoutSessionMixin):
 
         return HttpResponseRedirect(reverse('checkout:thank-you'))
 
-    def place_order(self, order_number, basket, total_incl_tax, total_excl_tax, **kwargs):
+    def place_order(self, order_number, basket, total_incl_tax,
+                    total_excl_tax, user=None, **kwargs):
         """
         Writes the order out to the DB including the payment models
         """
-        shipping_address = self.create_shipping_address()
+        shipping_address = self.create_shipping_address(basket)
         shipping_method = self.get_shipping_method(basket)
         billing_address = self.create_billing_address(shipping_address)
 
@@ -92,6 +95,11 @@ class OrderPlacementMixin(CheckoutSessionMixin):
         else:
             status = kwargs.pop('status')
 
+        # We allow a user to be passed in to handle cases where the order is
+        # being placed on behalf of someone else.
+        if user is None:
+            user = self.request.user
+
         # Set guest email address for anon checkout.   Some libraries (eg
         # PayPal) will pass this explicitly so we take care not to clobber.
         if not self.request.user.is_authenticated() and 'guest_email' not in kwargs:
@@ -100,7 +108,7 @@ class OrderPlacementMixin(CheckoutSessionMixin):
         order = OrderCreator().place_order(basket=basket,
                                            total_incl_tax=total_incl_tax,
                                            total_excl_tax=total_excl_tax,
-                                           user=self.request.user,
+                                           user=user,
                                            shipping_method=shipping_method,
                                            shipping_address=shipping_address,
                                            billing_address=billing_address,
@@ -110,7 +118,7 @@ class OrderPlacementMixin(CheckoutSessionMixin):
         self.save_payment_details(order)
         return order
 
-    def create_shipping_address(self):
+    def create_shipping_address(self, basket=None):
         """
         Create and returns the shipping address for the current order.
 
@@ -122,7 +130,9 @@ class OrderPlacementMixin(CheckoutSessionMixin):
         If the shipping address was selected from the user's address book,
         then we convert the UserAddress to a ShippingAddress.
         """
-        if not self.request.basket.is_shipping_required():
+        if basket is None:
+            basket = self.request.basket
+        if not basket.is_shipping_required():
             return None
 
         addr_data = self.checkout_session.new_shipping_address_fields()
@@ -258,4 +268,4 @@ class OrderPlacementMixin(CheckoutSessionMixin):
             dispatcher = Dispatcher(logger)
             dispatcher.dispatch_order_messages(order, messages, event_type, **kwargs)
         else:
-            logger.warning("Order #%s - no %s communication event type", order.number, code)
\ No newline at end of file
+            logger.warning("Order #%s - no %s communication event type", order.number, code)
